[![Test](https://github.com/cloudmatos/matos-aws-provider/actions/workflows/test.yaml/badge.svg?branch=main)](https://github.com/cloudmatos/matos-aws-provider/actions/workflows/test.yaml)
[![Pylint](https://github.com/cloudmatos/matos-aws-provider/actions/workflows/pylint.yml/badge.svg?branch=main)](https://github.com/cloudmatos/matos-aws-provider/actions/workflows/pylint.yml)

# Matos Python AWS provider

This is a python package for aws provider service. 
It interacts with aws native cloud services api's or third party tools to deduce current status and metadata of underlying resources. update
